@@ -1,11 +1,5 @@
-.packageName <- "pheno"
-
-.First.lib <- function(lib, pkg) {
-        library.dynam("pheno", pkg, lib)
-        print("pheno library loaded")
-}
 # Finds connected data sets of a numeric matrix M
-# non-entries are considered 0
+# missing values are assumeds to be NA or 0.
 # Returns two vectors: 
 # rowclasses[0..maxnr-1] : Class number of the respective rows
 # colclasses[0..maxnc-1] : Class number of the respective cols
@@ -14,9 +8,15 @@ connectedSets <- function(M) {
 	maxnr <- dim(M)[1]
 	maxnc <- dim(M)[2]
 
+	# set NA values to 0
+	for(i in 1:maxnr) {
+		for(j in 1:maxnc) { 
+			if(is.na(M[i,j])) { M[i,j] <- 0 }
+		}
+	}
 	res <- .C("connectivity",M=as.vector(t(M),"numeric"),nrows=as.integer(maxnr),ncols=as.integer(maxnc),rowclasses=vector("integer",maxnr),colclasses=vector("integer",maxnc),PACKAGE="pheno")
 	
 	attach(res)
-	return(rowclasses,colclasses)
+	return(list(rowclasses=rowclasses, colclasses=colclasses))
 
 }
