@@ -3,10 +3,10 @@
 # declination: angle between sun rays and equatorial plane for 
 # the whole earth (-23 degrees - + 23 degrees)
 daylength <- function(i,l) {
-		
+	if(!is.integer(i)) stop("daylength: first argument must be an integer. Exiting ...")	
 	res <- .C("daylength",l=as.double(l),i=as.integer(i),dl=double(1),delta=double(1),PACKAGE="pheno")
 	
 	attach(res)
-	return(dl,delta)
+	return(list(dl=dl, delata=delta))
 
 }
